logical.hpp

The logical.hpp includes the headers in the logical folder.

#### Usage

#include <boost/preprocessor/logical.hpp>

#### Includes

- <boost/preprocessor/logical/and.hpp>
- <boost/preprocessor/logical/bitand.hpp>
- <boost/preprocessor/logical/bitnor.hpp>
- <boost/preprocessor/logical/bitor.hpp>
- <boost/preprocessor/logical/bitxor.hpp>
- <boost/preprocessor/logical/bool.hpp>
- <boost/preprocessor/logical/compl.hpp>
- <boost/preprocessor/logical/nor.hpp>
- <boost/preprocessor/logical/not.hpp>
- <boost/preprocessor/logical/or.hpp>
- <boost/preprocessor/logical/xor.hpp>

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)